.. MADAP documentation master file, created by
   sphinx-quickstart on Mon Jul 25 21:56:34 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MADAP's documentation!
=================================

   This documentation is generated from the MADAP source code. It is
   intended to be used by developers and users of MADAP.

What is MADAP?
--------------

This is MADAP, a software package for the analysis of electrochemical data.

.. toctree::
   :maxdepth: 6
   :caption: Packages:

   generated_arrhenius/modules
   generated_impedance/modules
   generated_voltammetry/modules

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
